import { FastifyInstance } from 'fastify';
import { add, AddFunctionOptions } from '@modal-sh/core';

export const addRoutes = (server: FastifyInstance) => {
	server.post('/', async (request, reply) => {
		const { a, b } = request.body as AddFunctionOptions;
		try {
			const response = add({a, b});
			reply.send(response);
		} catch (errorRaw) {
			if (errorRaw instanceof TypeError) {
				reply.status(400).send(errorRaw.message);
			} else if (errorRaw instanceof RangeError) {
				reply.status(400).send(errorRaw.message);
			} else {
				const error = errorRaw as Error;
				reply.status(500).send(error.message);
			}
		}
	});

	return server;
};
